package com.da.dangan.mapper;

import com.da.dangan.domain.DaBookshelf;

import java.util.List;

/**
 * 物理书架Mapper接口
 * 
 * @author hs
 * @date 2024-05-11
 */
public interface DaBookshelfMapper 
{
    /**
     * 查询物理书架
     * 
     * @param shelfId 物理书架主键
     * @return 物理书架
     */
    public DaBookshelf selectDaBookshelfByShelfId(Long shelfId);

    /**
     * 查询物理书架列表
     * 
     * @param daBookshelf 物理书架
     * @return 物理书架集合
     */
    public List<DaBookshelf> selectDaBookshelfList(DaBookshelf daBookshelf);

    /**
     * 新增物理书架
     * 
     * @param daBookshelf 物理书架
     * @return 结果
     */
    public int insertDaBookshelf(DaBookshelf daBookshelf);

    /**
     * 修改物理书架
     * 
     * @param daBookshelf 物理书架
     * @return 结果
     */
    public int updateDaBookshelf(DaBookshelf daBookshelf);

    /**
     * 删除物理书架
     * 
     * @param shelfId 物理书架主键
     * @return 结果
     */
    public int deleteDaBookshelfByShelfId(Long shelfId);

    /**
     * 批量删除物理书架
     * 
     * @param shelfIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDaBookshelfByShelfIds(Long[] shelfIds);
}
